@@ -1,7 +1,17 @@
 package Class::Date;
-use Time::Local qw(timegm timelocal);
+use Time::Local;
+BEGIN {
+    if (exists $Time::Local::{timelocal_nocheck}) {
+        *timelocal = *Time::Local::timelocal_nocheck;
+        *timegm = *Time::Local::timegm_nocheck;
+    } else {
+        *timelocal = *Time::Local::timelocal;
+        *timegm = *Time::Local::timegm;
+        
+    }
+}
 
-# $Id: Date.pm,v 1.19 2001/07/04 10:42:59 dlux Exp $
+# $Id: Date.pm,v 1.2 2001/10/11 10:45:18 dlux Exp $
 
 require 5.005;
 
@@ -43,7 +53,7 @@ BEGIN {
 
 }
 
-$VERSION = '1.0.4';
+$VERSION = '1.0.6';
 Class::Date->bootstrap($VERSION);
 
 $DST_ADJUST = 1;
@@ -228,6 +238,7 @@ sub _recalc_from_struct {
     $s->[c_yday]  = 0;
     $s->[c_epoch] = 0; # these are required to suppress warinngs;
     eval {
+        local $SIG{__WARN__} = sub { };
         $s->[c_epoch] = $s->[c_isgmt] ?
             timegm(@{$s}[c_sec,c_min,c_hour,c_day,c_mon,c_year]) :
             timelocal(@{$s}[c_sec,c_min,c_hour,c_day,c_mon,c_year]);
@@ -395,10 +406,7 @@ sub month_begin { my ($s)=@_;
 }
 
 sub month_end { my ($s)=@_;
-  my $aref = $s->aref;
-  $aref->[2] = 1;
-  $aref->[1]++; # It will be normalized
-  return $s->new($aref)-'1D';
+  return $s->clone(day => 1)+'1M'-'1D';
 }
 
 sub days_in_month {
@@ -636,7 +644,7 @@ use overload
   '<=>'    => "compare",
   'cmp'    => "compare",
   '+'      => "zero",
-  'neg'    => "true",
+  '!'      => "true",
   fallback => 1;
                 
 sub empty { "" }
@@ -1213,7 +1221,7 @@ this module. As you see in the previous section, the focus of development is
 not the speed until 1.0.  For fast date and datetime calculations, use 
 Date::Calc instead.
 
-=head1 BUGS
+=head1 BUGS AND LIMITATIONS
 
 =over 4
 
@@ -1226,6 +1234,22 @@ will fix this with new time_t in libc. If you really need dates over 2038,
 you need to completely rewrite this module or use Date::Calc or other date 
 modules.
 
+=item *
+
+This module uses Time::Local, and when it croaks, Class::Date returns
+"Invalid date or time" error message. Time::Local is different in the 5.005
+and 5.6.x version of perl, so the following code will return different
+results:
+
+  $a = date("2006-11-11")->clone(year => -1);
+
+In perl 5.6.1, it returns an invalid date with error message "Invali date or
+time", in perl 5.005 it returns an invalid date with range check error. Both
+are false if you use them in boolean context though, only the error message
+is different, but don't rely on the error message in this case. It however
+works in the same way if you change other fields than "year" to an invalid
+field.
+
 =back
 
 =head1 COPYRIGHT
@@ -1247,6 +1271,7 @@ Portions Copiright (c) Matt Sergeant
     (Lots of code are borrowed from the Time::Object module)
   - Tatsuhiko Miyagawa <miyagawa@cpan.org> (bugfixes)
   - Stas Bekman <stas@stason.org> (suggestions, bugfix)
+  - Chris Winters <chris@cwinters.com> (win32 .ppd version)
 
 =head1 SEE ALSO
 
